# coding: utf-8

"""
    Billingo API v3

    This is a Billingo API v3 documentation. Our API based on REST software architectural style. API has resource-oriented URLs, accepts JSON-encoded request bodies and returns JSON-encoded responses. To use this API you have to generate a new API key on our [site](https://app.billingo.hu/api-key). After that, you can test your API key on this page.  # noqa: E501

    OpenAPI spec version: 3.0.14
    Contact: hello@billingo.hu
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class DocumentBankAccount(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'name': 'str',
        'account_number': 'str',
        'account_number_iban': 'str',
        'swift': 'str'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'account_number': 'account_number',
        'account_number_iban': 'account_number_iban',
        'swift': 'swift'
    }

    def __init__(self, id=None, name=None, account_number=None, account_number_iban=None, swift=None):  # noqa: E501
        """DocumentBankAccount - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._name = None
        self._account_number = None
        self._account_number_iban = None
        self._swift = None
        self.discriminator = None
        if id is not None:
            self.id = id
        self.name = name
        self.account_number = account_number
        if account_number_iban is not None:
            self.account_number_iban = account_number_iban
        if swift is not None:
            self.swift = swift

    @property
    def id(self):
        """Gets the id of this DocumentBankAccount.  # noqa: E501


        :return: The id of this DocumentBankAccount.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DocumentBankAccount.


        :param id: The id of this DocumentBankAccount.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this DocumentBankAccount.  # noqa: E501


        :return: The name of this DocumentBankAccount.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DocumentBankAccount.


        :param name: The name of this DocumentBankAccount.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def account_number(self):
        """Gets the account_number of this DocumentBankAccount.  # noqa: E501


        :return: The account_number of this DocumentBankAccount.  # noqa: E501
        :rtype: str
        """
        return self._account_number

    @account_number.setter
    def account_number(self, account_number):
        """Sets the account_number of this DocumentBankAccount.


        :param account_number: The account_number of this DocumentBankAccount.  # noqa: E501
        :type: str
        """
        if account_number is None:
            raise ValueError("Invalid value for `account_number`, must not be `None`")  # noqa: E501

        self._account_number = account_number

    @property
    def account_number_iban(self):
        """Gets the account_number_iban of this DocumentBankAccount.  # noqa: E501


        :return: The account_number_iban of this DocumentBankAccount.  # noqa: E501
        :rtype: str
        """
        return self._account_number_iban

    @account_number_iban.setter
    def account_number_iban(self, account_number_iban):
        """Sets the account_number_iban of this DocumentBankAccount.


        :param account_number_iban: The account_number_iban of this DocumentBankAccount.  # noqa: E501
        :type: str
        """

        self._account_number_iban = account_number_iban

    @property
    def swift(self):
        """Gets the swift of this DocumentBankAccount.  # noqa: E501


        :return: The swift of this DocumentBankAccount.  # noqa: E501
        :rtype: str
        """
        return self._swift

    @swift.setter
    def swift(self, swift):
        """Sets the swift of this DocumentBankAccount.


        :param swift: The swift of this DocumentBankAccount.  # noqa: E501
        :type: str
        """

        self._swift = swift

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DocumentBankAccount, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DocumentBankAccount):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Billingo API v3

    This is a Billingo API v3 documentation. Our API based on REST software architectural style. API has resource-oriented URLs, accepts JSON-encoded request bodies and returns JSON-encoded responses. To use this API you have to generate a new API key on our [site](https://app.billingo.hu/api-key). After that, you can test your API key on this page.  # noqa: E501

    OpenAPI spec version: 3.0.14
    Contact: hello@billingo.hu
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Document(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'invoice_number': 'str',
        'type': 'DocumentType',
        'cancelled': 'bool',
        'block_id': 'int',
        'payment_status': 'PaymentStatus',
        'payment_method': 'PaymentMethod',
        'gross_total': 'float',
        'currency': 'Currency',
        'conversion_rate': 'float',
        'invoice_date': 'date',
        'fulfillment_date': 'date',
        'due_date': 'date',
        'paid_date': 'date',
        'organization': 'DocumentOrganization',
        'partner': 'Partner',
        'document_partner': 'DocumentPartner',
        'electronic': 'bool',
        'comment': 'str',
        'tags': 'list[str]',
        'notification_status': 'DocumentNotificationStatus',
        'language': 'DocumentLanguage',
        'items': 'list[DocumentItem]',
        'summary': 'DocumentSummary',
        'settings': 'DocumentSettings',
        'online_szamla_status': 'OnlineSzamlaStatusEnum',
        'related_documents': 'list[DocumentAncestor]',
        'discount': 'Discount',
        'correction_type': 'CorrectionType'
    }

    attribute_map = {
        'id': 'id',
        'invoice_number': 'invoice_number',
        'type': 'type',
        'cancelled': 'cancelled',
        'block_id': 'block_id',
        'payment_status': 'payment_status',
        'payment_method': 'payment_method',
        'gross_total': 'gross_total',
        'currency': 'currency',
        'conversion_rate': 'conversion_rate',
        'invoice_date': 'invoice_date',
        'fulfillment_date': 'fulfillment_date',
        'due_date': 'due_date',
        'paid_date': 'paid_date',
        'organization': 'organization',
        'partner': 'partner',
        'document_partner': 'document_partner',
        'electronic': 'electronic',
        'comment': 'comment',
        'tags': 'tags',
        'notification_status': 'notification_status',
        'language': 'language',
        'items': 'items',
        'summary': 'summary',
        'settings': 'settings',
        'online_szamla_status': 'online_szamla_status',
        'related_documents': 'related_documents',
        'discount': 'discount',
        'correction_type': 'correction_type'
    }

    def __init__(self, id=None, invoice_number=None, type=None, cancelled=None, block_id=None, payment_status=None, payment_method=None, gross_total=None, currency=None, conversion_rate=None, invoice_date=None, fulfillment_date=None, due_date=None, paid_date=None, organization=None, partner=None, document_partner=None, electronic=None, comment=None, tags=None, notification_status=None, language=None, items=None, summary=None, settings=None, online_szamla_status=None, related_documents=None, discount=None, correction_type=None):  # noqa: E501
        """Document - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._invoice_number = None
        self._type = None
        self._cancelled = None
        self._block_id = None
        self._payment_status = None
        self._payment_method = None
        self._gross_total = None
        self._currency = None
        self._conversion_rate = None
        self._invoice_date = None
        self._fulfillment_date = None
        self._due_date = None
        self._paid_date = None
        self._organization = None
        self._partner = None
        self._document_partner = None
        self._electronic = None
        self._comment = None
        self._tags = None
        self._notification_status = None
        self._language = None
        self._items = None
        self._summary = None
        self._settings = None
        self._online_szamla_status = None
        self._related_documents = None
        self._discount = None
        self._correction_type = None
        self.discriminator = None
        if id is not None:
            self.id = id
        if invoice_number is not None:
            self.invoice_number = invoice_number
        if type is not None:
            self.type = type
        if cancelled is not None:
            self.cancelled = cancelled
        if block_id is not None:
            self.block_id = block_id
        if payment_status is not None:
            self.payment_status = payment_status
        if payment_method is not None:
            self.payment_method = payment_method
        if gross_total is not None:
            self.gross_total = gross_total
        if currency is not None:
            self.currency = currency
        if conversion_rate is not None:
            self.conversion_rate = conversion_rate
        if invoice_date is not None:
            self.invoice_date = invoice_date
        if fulfillment_date is not None:
            self.fulfillment_date = fulfillment_date
        if due_date is not None:
            self.due_date = due_date
        if paid_date is not None:
            self.paid_date = paid_date
        if organization is not None:
            self.organization = organization
        if partner is not None:
            self.partner = partner
        if document_partner is not None:
            self.document_partner = document_partner
        if electronic is not None:
            self.electronic = electronic
        if comment is not None:
            self.comment = comment
        if tags is not None:
            self.tags = tags
        if notification_status is not None:
            self.notification_status = notification_status
        if language is not None:
            self.language = language
        if items is not None:
            self.items = items
        if summary is not None:
            self.summary = summary
        if settings is not None:
            self.settings = settings
        if online_szamla_status is not None:
            self.online_szamla_status = online_szamla_status
        if related_documents is not None:
            self.related_documents = related_documents
        if discount is not None:
            self.discount = discount
        if correction_type is not None:
            self.correction_type = correction_type

    @property
    def id(self):
        """Gets the id of this Document.  # noqa: E501

        The document's unique identifier.  # noqa: E501

        :return: The id of this Document.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Document.

        The document's unique identifier.  # noqa: E501

        :param id: The id of this Document.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def invoice_number(self):
        """Gets the invoice_number of this Document.  # noqa: E501

        The document's invoice number.  # noqa: E501

        :return: The invoice_number of this Document.  # noqa: E501
        :rtype: str
        """
        return self._invoice_number

    @invoice_number.setter
    def invoice_number(self, invoice_number):
        """Sets the invoice_number of this Document.

        The document's invoice number.  # noqa: E501

        :param invoice_number: The invoice_number of this Document.  # noqa: E501
        :type: str
        """

        self._invoice_number = invoice_number

    @property
    def type(self):
        """Gets the type of this Document.  # noqa: E501


        :return: The type of this Document.  # noqa: E501
        :rtype: DocumentType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this Document.


        :param type: The type of this Document.  # noqa: E501
        :type: DocumentType
        """

        self._type = type

    @property
    def cancelled(self):
        """Gets the cancelled of this Document.  # noqa: E501


        :return: The cancelled of this Document.  # noqa: E501
        :rtype: bool
        """
        return self._cancelled

    @cancelled.setter
    def cancelled(self, cancelled):
        """Sets the cancelled of this Document.


        :param cancelled: The cancelled of this Document.  # noqa: E501
        :type: bool
        """

        self._cancelled = cancelled

    @property
    def block_id(self):
        """Gets the block_id of this Document.  # noqa: E501

        DocumentBlock's identifier.  # noqa: E501

        :return: The block_id of this Document.  # noqa: E501
        :rtype: int
        """
        return self._block_id

    @block_id.setter
    def block_id(self, block_id):
        """Sets the block_id of this Document.

        DocumentBlock's identifier.  # noqa: E501

        :param block_id: The block_id of this Document.  # noqa: E501
        :type: int
        """

        self._block_id = block_id

    @property
    def payment_status(self):
        """Gets the payment_status of this Document.  # noqa: E501


        :return: The payment_status of this Document.  # noqa: E501
        :rtype: PaymentStatus
        """
        return self._payment_status

    @payment_status.setter
    def payment_status(self, payment_status):
        """Sets the payment_status of this Document.


        :param payment_status: The payment_status of this Document.  # noqa: E501
        :type: PaymentStatus
        """

        self._payment_status = payment_status

    @property
    def payment_method(self):
        """Gets the payment_method of this Document.  # noqa: E501


        :return: The payment_method of this Document.  # noqa: E501
        :rtype: PaymentMethod
        """
        return self._payment_method

    @payment_method.setter
    def payment_method(self, payment_method):
        """Sets the payment_method of this Document.


        :param payment_method: The payment_method of this Document.  # noqa: E501
        :type: PaymentMethod
        """

        self._payment_method = payment_method

    @property
    def gross_total(self):
        """Gets the gross_total of this Document.  # noqa: E501

        The document's gross total price.  # noqa: E501

        :return: The gross_total of this Document.  # noqa: E501
        :rtype: float
        """
        return self._gross_total

    @gross_total.setter
    def gross_total(self, gross_total):
        """Sets the gross_total of this Document.

        The document's gross total price.  # noqa: E501

        :param gross_total: The gross_total of this Document.  # noqa: E501
        :type: float
        """

        self._gross_total = gross_total

    @property
    def currency(self):
        """Gets the currency of this Document.  # noqa: E501


        :return: The currency of this Document.  # noqa: E501
        :rtype: Currency
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this Document.


        :param currency: The currency of this Document.  # noqa: E501
        :type: Currency
        """

        self._currency = currency

    @property
    def conversion_rate(self):
        """Gets the conversion_rate of this Document.  # noqa: E501


        :return: The conversion_rate of this Document.  # noqa: E501
        :rtype: float
        """
        return self._conversion_rate

    @conversion_rate.setter
    def conversion_rate(self, conversion_rate):
        """Sets the conversion_rate of this Document.


        :param conversion_rate: The conversion_rate of this Document.  # noqa: E501
        :type: float
        """

        self._conversion_rate = conversion_rate

    @property
    def invoice_date(self):
        """Gets the invoice_date of this Document.  # noqa: E501


        :return: The invoice_date of this Document.  # noqa: E501
        :rtype: date
        """
        return self._invoice_date

    @invoice_date.setter
    def invoice_date(self, invoice_date):
        """Sets the invoice_date of this Document.


        :param invoice_date: The invoice_date of this Document.  # noqa: E501
        :type: date
        """

        self._invoice_date = invoice_date

    @property
    def fulfillment_date(self):
        """Gets the fulfillment_date of this Document.  # noqa: E501


        :return: The fulfillment_date of this Document.  # noqa: E501
        :rtype: date
        """
        return self._fulfillment_date

    @fulfillment_date.setter
    def fulfillment_date(self, fulfillment_date):
        """Sets the fulfillment_date of this Document.


        :param fulfillment_date: The fulfillment_date of this Document.  # noqa: E501
        :type: date
        """

        self._fulfillment_date = fulfillment_date

    @property
    def due_date(self):
        """Gets the due_date of this Document.  # noqa: E501


        :return: The due_date of this Document.  # noqa: E501
        :rtype: date
        """
        return self._due_date

    @due_date.setter
    def due_date(self, due_date):
        """Sets the due_date of this Document.


        :param due_date: The due_date of this Document.  # noqa: E501
        :type: date
        """

        self._due_date = due_date

    @property
    def paid_date(self):
        """Gets the paid_date of this Document.  # noqa: E501


        :return: The paid_date of this Document.  # noqa: E501
        :rtype: date
        """
        return self._paid_date

    @paid_date.setter
    def paid_date(self, paid_date):
        """Sets the paid_date of this Document.


        :param paid_date: The paid_date of this Document.  # noqa: E501
        :type: date
        """

        self._paid_date = paid_date

    @property
    def organization(self):
        """Gets the organization of this Document.  # noqa: E501


        :return: The organization of this Document.  # noqa: E501
        :rtype: DocumentOrganization
        """
        return self._organization

    @organization.setter
    def organization(self, organization):
        """Sets the organization of this Document.


        :param organization: The organization of this Document.  # noqa: E501
        :type: DocumentOrganization
        """

        self._organization = organization

    @property
    def partner(self):
        """Gets the partner of this Document.  # noqa: E501


        :return: The partner of this Document.  # noqa: E501
        :rtype: Partner
        """
        return self._partner

    @partner.setter
    def partner(self, partner):
        """Sets the partner of this Document.


        :param partner: The partner of this Document.  # noqa: E501
        :type: Partner
        """

        self._partner = partner

    @property
    def document_partner(self):
        """Gets the document_partner of this Document.  # noqa: E501


        :return: The document_partner of this Document.  # noqa: E501
        :rtype: DocumentPartner
        """
        return self._document_partner

    @document_partner.setter
    def document_partner(self, document_partner):
        """Sets the document_partner of this Document.


        :param document_partner: The document_partner of this Document.  # noqa: E501
        :type: DocumentPartner
        """

        self._document_partner = document_partner

    @property
    def electronic(self):
        """Gets the electronic of this Document.  # noqa: E501


        :return: The electronic of this Document.  # noqa: E501
        :rtype: bool
        """
        return self._electronic

    @electronic.setter
    def electronic(self, electronic):
        """Sets the electronic of this Document.


        :param electronic: The electronic of this Document.  # noqa: E501
        :type: bool
        """

        self._electronic = electronic

    @property
    def comment(self):
        """Gets the comment of this Document.  # noqa: E501


        :return: The comment of this Document.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this Document.


        :param comment: The comment of this Document.  # noqa: E501
        :type: str
        """

        self._comment = comment

    @property
    def tags(self):
        """Gets the tags of this Document.  # noqa: E501


        :return: The tags of this Document.  # noqa: E501
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this Document.


        :param tags: The tags of this Document.  # noqa: E501
        :type: list[str]
        """

        self._tags = tags

    @property
    def notification_status(self):
        """Gets the notification_status of this Document.  # noqa: E501


        :return: The notification_status of this Document.  # noqa: E501
        :rtype: DocumentNotificationStatus
        """
        return self._notification_status

    @notification_status.setter
    def notification_status(self, notification_status):
        """Sets the notification_status of this Document.


        :param notification_status: The notification_status of this Document.  # noqa: E501
        :type: DocumentNotificationStatus
        """

        self._notification_status = notification_status

    @property
    def language(self):
        """Gets the language of this Document.  # noqa: E501


        :return: The language of this Document.  # noqa: E501
        :rtype: DocumentLanguage
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this Document.


        :param language: The language of this Document.  # noqa: E501
        :type: DocumentLanguage
        """

        self._language = language

    @property
    def items(self):
        """Gets the items of this Document.  # noqa: E501


        :return: The items of this Document.  # noqa: E501
        :rtype: list[DocumentItem]
        """
        return self._items

    @items.setter
    def items(self, items):
        """Sets the items of this Document.


        :param items: The items of this Document.  # noqa: E501
        :type: list[DocumentItem]
        """

        self._items = items

    @property
    def summary(self):
        """Gets the summary of this Document.  # noqa: E501


        :return: The summary of this Document.  # noqa: E501
        :rtype: DocumentSummary
        """
        return self._summary

    @summary.setter
    def summary(self, summary):
        """Sets the summary of this Document.


        :param summary: The summary of this Document.  # noqa: E501
        :type: DocumentSummary
        """

        self._summary = summary

    @property
    def settings(self):
        """Gets the settings of this Document.  # noqa: E501


        :return: The settings of this Document.  # noqa: E501
        :rtype: DocumentSettings
        """
        return self._settings

    @settings.setter
    def settings(self, settings):
        """Sets the settings of this Document.


        :param settings: The settings of this Document.  # noqa: E501
        :type: DocumentSettings
        """

        self._settings = settings

    @property
    def online_szamla_status(self):
        """Gets the online_szamla_status of this Document.  # noqa: E501


        :return: The online_szamla_status of this Document.  # noqa: E501
        :rtype: OnlineSzamlaStatusEnum
        """
        return self._online_szamla_status

    @online_szamla_status.setter
    def online_szamla_status(self, online_szamla_status):
        """Sets the online_szamla_status of this Document.


        :param online_szamla_status: The online_szamla_status of this Document.  # noqa: E501
        :type: OnlineSzamlaStatusEnum
        """

        self._online_szamla_status = online_szamla_status

    @property
    def related_documents(self):
        """Gets the related_documents of this Document.  # noqa: E501


        :return: The related_documents of this Document.  # noqa: E501
        :rtype: list[DocumentAncestor]
        """
        return self._related_documents

    @related_documents.setter
    def related_documents(self, related_documents):
        """Sets the related_documents of this Document.


        :param related_documents: The related_documents of this Document.  # noqa: E501
        :type: list[DocumentAncestor]
        """

        self._related_documents = related_documents

    @property
    def discount(self):
        """Gets the discount of this Document.  # noqa: E501


        :return: The discount of this Document.  # noqa: E501
        :rtype: Discount
        """
        return self._discount

    @discount.setter
    def discount(self, discount):
        """Sets the discount of this Document.


        :param discount: The discount of this Document.  # noqa: E501
        :type: Discount
        """

        self._discount = discount

    @property
    def correction_type(self):
        """Gets the correction_type of this Document.  # noqa: E501


        :return: The correction_type of this Document.  # noqa: E501
        :rtype: CorrectionType
        """
        return self._correction_type

    @correction_type.setter
    def correction_type(self, correction_type):
        """Sets the correction_type of this Document.


        :param correction_type: The correction_type of this Document.  # noqa: E501
        :type: CorrectionType
        """

        self._correction_type = correction_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Document, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Document):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Billingo API v3

    This is a Billingo API v3 documentation. Our API based on REST software architectural style. API has resource-oriented URLs, accepts JSON-encoded request bodies and returns JSON-encoded responses. To use this API you have to generate a new API key on our [site](https://app.billingo.hu/api-key). After that, you can test your API key on this page.  # noqa: E501

    OpenAPI spec version: 3.0.14
    Contact: hello@billingo.hu
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import billingo
from billingo.api.document_api import DocumentApi  # noqa: E501
from billingo.rest import ApiException


class TestDocumentApi(unittest.TestCase):
    """DocumentApi unit test stubs"""

    def setUp(self):
        self.api = DocumentApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_archive_document(self):
        """Test case for archive_document

        Archive a proforma document.  # noqa: E501
        """
        pass

    def test_cancel_document(self):
        """Test case for cancel_document

        Cancel a document  # noqa: E501
        """
        pass

    def test_create_document(self):
        """Test case for create_document

        Create a document  # noqa: E501
        """
        pass

    def test_create_document_from_draft(self):
        """Test case for create_document_from_draft

        Converts a draft to an invoice.  # noqa: E501
        """
        pass

    def test_create_document_from_proforma(self):
        """Test case for create_document_from_proforma

        Create a document from proforma.  # noqa: E501
        """
        pass

    def test_create_modification_document(self):
        """Test case for create_modification_document

        Create a modification document.  # noqa: E501
        """
        pass

    def test_create_receipt(self):
        """Test case for create_receipt

        Create a receipt  # noqa: E501
        """
        pass

    def test_create_receipt_from_draft(self):
        """Test case for create_receipt_from_draft

        Converts a draft to a receipt.  # noqa: E501
        """
        pass

    def test_delete_document(self):
        """Test case for delete_document

        Delete a draft.  # noqa: E501
        """
        pass

    def test_delete_payment(self):
        """Test case for delete_payment

        Delete all payment history on document  # noqa: E501
        """
        pass

    def test_document_copy(self):
        """Test case for document_copy

        Copy a document  # noqa: E501
        """
        pass

    def test_download_document(self):
        """Test case for download_document

        Download a document in PDF format.  # noqa: E501
        """
        pass

    def test_get_document(self):
        """Test case for get_document

        Retrieve a document  # noqa: E501
        """
        pass

    def test_get_document_by_vendor_id(self):
        """Test case for get_document_by_vendor_id

        Retrieve a document by vendor id  # noqa: E501
        """
        pass

    def test_get_online_szamla_status(self):
        """Test case for get_online_szamla_status

        Retrieve a document Online Számla status  # noqa: E501
        """
        pass

    def test_get_payment(self):
        """Test case for get_payment

        Retrieve a payment histroy  # noqa: E501
        """
        pass

    def test_get_public_url(self):
        """Test case for get_public_url

        Retrieve a document download public url.  # noqa: E501
        """
        pass

    def test_list_document(self):
        """Test case for list_document

        List all documents  # noqa: E501
        """
        pass

    def test_pos_print(self):
        """Test case for pos_print

        Returns a printable POS PDF  # noqa: E501
        """
        pass

    def test_send_document(self):
        """Test case for send_document

        Send invoice to given email adresses.  # noqa: E501
        """
        pass

    def test_update_payment(self):
        """Test case for update_payment

        Update payment history  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Billingo API v3

    This is a Billingo API v3 documentation. Our API based on REST software architectural style. API has resource-oriented URLs, accepts JSON-encoded request bodies and returns JSON-encoded responses. To use this API you have to generate a new API key on our [site](https://app.billingo.hu/api-key). After that, you can test your API key on this page.  # noqa: E501

    OpenAPI spec version: 3.0.14
    Contact: hello@billingo.hu
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import billingo
from billingo.api.product_api import ProductApi  # noqa: E501
from billingo.rest import ApiException


class TestProductApi(unittest.TestCase):
    """ProductApi unit test stubs"""

    def setUp(self):
        self.api = ProductApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_product(self):
        """Test case for create_product

        Create a product  # noqa: E501
        """
        pass

    def test_delete_product(self):
        """Test case for delete_product

        Delete a product  # noqa: E501
        """
        pass

    def test_get_product(self):
        """Test case for get_product

        Retrieve a product  # noqa: E501
        """
        pass

    def test_list_product(self):
        """Test case for list_product

        List all product  # noqa: E501
        """
        pass

    def test_update_product(self):
        """Test case for update_product

        Update a product  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Billingo API v3

    This is a Billingo API v3 documentation. Our API based on REST software architectural style. API has resource-oriented URLs, accepts JSON-encoded request bodies and returns JSON-encoded responses. To use this API you have to generate a new API key on our [site](https://app.billingo.hu/api-key). After that, you can test your API key on this page.  # noqa: E501

    OpenAPI spec version: 3.0.14
    Contact: hello@billingo.hu
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class DocumentOrganization(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'tax_number': 'str',
        'bank_account': 'DocumentBankAccount',
        'address': 'Address',
        'small_taxpayer': 'bool',
        'ev_number': 'str',
        'eu_tax_number': 'str',
        'cash_settled': 'bool'
    }

    attribute_map = {
        'name': 'name',
        'tax_number': 'tax_number',
        'bank_account': 'bank_account',
        'address': 'address',
        'small_taxpayer': 'small_taxpayer',
        'ev_number': 'ev_number',
        'eu_tax_number': 'eu_tax_number',
        'cash_settled': 'cash_settled'
    }

    def __init__(self, name=None, tax_number=None, bank_account=None, address=None, small_taxpayer=None, ev_number=None, eu_tax_number=None, cash_settled=None):  # noqa: E501
        """DocumentOrganization - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._tax_number = None
        self._bank_account = None
        self._address = None
        self._small_taxpayer = None
        self._ev_number = None
        self._eu_tax_number = None
        self._cash_settled = None
        self.discriminator = None
        if name is not None:
            self.name = name
        if tax_number is not None:
            self.tax_number = tax_number
        if bank_account is not None:
            self.bank_account = bank_account
        if address is not None:
            self.address = address
        if small_taxpayer is not None:
            self.small_taxpayer = small_taxpayer
        if ev_number is not None:
            self.ev_number = ev_number
        if eu_tax_number is not None:
            self.eu_tax_number = eu_tax_number
        if cash_settled is not None:
            self.cash_settled = cash_settled

    @property
    def name(self):
        """Gets the name of this DocumentOrganization.  # noqa: E501


        :return: The name of this DocumentOrganization.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DocumentOrganization.


        :param name: The name of this DocumentOrganization.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def tax_number(self):
        """Gets the tax_number of this DocumentOrganization.  # noqa: E501


        :return: The tax_number of this DocumentOrganization.  # noqa: E501
        :rtype: str
        """
        return self._tax_number

    @tax_number.setter
    def tax_number(self, tax_number):
        """Sets the tax_number of this DocumentOrganization.


        :param tax_number: The tax_number of this DocumentOrganization.  # noqa: E501
        :type: str
        """

        self._tax_number = tax_number

    @property
    def bank_account(self):
        """Gets the bank_account of this DocumentOrganization.  # noqa: E501


        :return: The bank_account of this DocumentOrganization.  # noqa: E501
        :rtype: DocumentBankAccount
        """
        return self._bank_account

    @bank_account.setter
    def bank_account(self, bank_account):
        """Sets the bank_account of this DocumentOrganization.


        :param bank_account: The bank_account of this DocumentOrganization.  # noqa: E501
        :type: DocumentBankAccount
        """

        self._bank_account = bank_account

    @property
    def address(self):
        """Gets the address of this DocumentOrganization.  # noqa: E501


        :return: The address of this DocumentOrganization.  # noqa: E501
        :rtype: Address
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this DocumentOrganization.


        :param address: The address of this DocumentOrganization.  # noqa: E501
        :type: Address
        """

        self._address = address

    @property
    def small_taxpayer(self):
        """Gets the small_taxpayer of this DocumentOrganization.  # noqa: E501


        :return: The small_taxpayer of this DocumentOrganization.  # noqa: E501
        :rtype: bool
        """
        return self._small_taxpayer

    @small_taxpayer.setter
    def small_taxpayer(self, small_taxpayer):
        """Sets the small_taxpayer of this DocumentOrganization.


        :param small_taxpayer: The small_taxpayer of this DocumentOrganization.  # noqa: E501
        :type: bool
        """

        self._small_taxpayer = small_taxpayer

    @property
    def ev_number(self):
        """Gets the ev_number of this DocumentOrganization.  # noqa: E501


        :return: The ev_number of this DocumentOrganization.  # noqa: E501
        :rtype: str
        """
        return self._ev_number

    @ev_number.setter
    def ev_number(self, ev_number):
        """Sets the ev_number of this DocumentOrganization.


        :param ev_number: The ev_number of this DocumentOrganization.  # noqa: E501
        :type: str
        """

        self._ev_number = ev_number

    @property
    def eu_tax_number(self):
        """Gets the eu_tax_number of this DocumentOrganization.  # noqa: E501


        :return: The eu_tax_number of this DocumentOrganization.  # noqa: E501
        :rtype: str
        """
        return self._eu_tax_number

    @eu_tax_number.setter
    def eu_tax_number(self, eu_tax_number):
        """Sets the eu_tax_number of this DocumentOrganization.


        :param eu_tax_number: The eu_tax_number of this DocumentOrganization.  # noqa: E501
        :type: str
        """

        self._eu_tax_number = eu_tax_number

    @property
    def cash_settled(self):
        """Gets the cash_settled of this DocumentOrganization.  # noqa: E501


        :return: The cash_settled of this DocumentOrganization.  # noqa: E501
        :rtype: bool
        """
        return self._cash_settled

    @cash_settled.setter
    def cash_settled(self, cash_settled):
        """Sets the cash_settled of this DocumentOrganization.


        :param cash_settled: The cash_settled of this DocumentOrganization.  # noqa: E501
        :type: bool
        """

        self._cash_settled = cash_settled

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DocumentOrganization, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DocumentOrganization):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Billingo API v3

    This is a Billingo API v3 documentation. Our API based on REST software architectural style. API has resource-oriented URLs, accepts JSON-encoded request bodies and returns JSON-encoded responses. To use this API you have to generate a new API key on our [site](https://app.billingo.hu/api-key). After that, you can test your API key on this page.  # noqa: E501

    OpenAPI spec version: 3.0.14
    Contact: hello@billingo.hu
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PartnerCustomBillingSettings(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'payment_method': 'PaymentMethod',
        'document_form': 'DocumentForm',
        'due_days': 'int',
        'document_currency': 'Currency',
        'template_language_code': 'DocumentLanguage',
        'discount': 'Discount'
    }

    attribute_map = {
        'payment_method': 'payment_method',
        'document_form': 'document_form',
        'due_days': 'due_days',
        'document_currency': 'document_currency',
        'template_language_code': 'template_language_code',
        'discount': 'discount'
    }

    def __init__(self, payment_method=None, document_form=None, due_days=None, document_currency=None, template_language_code=None, discount=None):  # noqa: E501
        """PartnerCustomBillingSettings - a model defined in Swagger"""  # noqa: E501
        self._payment_method = None
        self._document_form = None
        self._due_days = None
        self._document_currency = None
        self._template_language_code = None
        self._discount = None
        self.discriminator = None
        if payment_method is not None:
            self.payment_method = payment_method
        if document_form is not None:
            self.document_form = document_form
        if due_days is not None:
            self.due_days = due_days
        if document_currency is not None:
            self.document_currency = document_currency
        if template_language_code is not None:
            self.template_language_code = template_language_code
        if discount is not None:
            self.discount = discount

    @property
    def payment_method(self):
        """Gets the payment_method of this PartnerCustomBillingSettings.  # noqa: E501


        :return: The payment_method of this PartnerCustomBillingSettings.  # noqa: E501
        :rtype: PaymentMethod
        """
        return self._payment_method

    @payment_method.setter
    def payment_method(self, payment_method):
        """Sets the payment_method of this PartnerCustomBillingSettings.


        :param payment_method: The payment_method of this PartnerCustomBillingSettings.  # noqa: E501
        :type: PaymentMethod
        """

        self._payment_method = payment_method

    @property
    def document_form(self):
        """Gets the document_form of this PartnerCustomBillingSettings.  # noqa: E501


        :return: The document_form of this PartnerCustomBillingSettings.  # noqa: E501
        :rtype: DocumentForm
        """
        return self._document_form

    @document_form.setter
    def document_form(self, document_form):
        """Sets the document_form of this PartnerCustomBillingSettings.


        :param document_form: The document_form of this PartnerCustomBillingSettings.  # noqa: E501
        :type: DocumentForm
        """

        self._document_form = document_form

    @property
    def due_days(self):
        """Gets the due_days of this PartnerCustomBillingSettings.  # noqa: E501


        :return: The due_days of this PartnerCustomBillingSettings.  # noqa: E501
        :rtype: int
        """
        return self._due_days

    @due_days.setter
    def due_days(self, due_days):
        """Sets the due_days of this PartnerCustomBillingSettings.


        :param due_days: The due_days of this PartnerCustomBillingSettings.  # noqa: E501
        :type: int
        """

        self._due_days = due_days

    @property
    def document_currency(self):
        """Gets the document_currency of this PartnerCustomBillingSettings.  # noqa: E501


        :return: The document_currency of this PartnerCustomBillingSettings.  # noqa: E501
        :rtype: Currency
        """
        return self._document_currency

    @document_currency.setter
    def document_currency(self, document_currency):
        """Sets the document_currency of this PartnerCustomBillingSettings.


        :param document_currency: The document_currency of this PartnerCustomBillingSettings.  # noqa: E501
        :type: Currency
        """

        self._document_currency = document_currency

    @property
    def template_language_code(self):
        """Gets the template_language_code of this PartnerCustomBillingSettings.  # noqa: E501


        :return: The template_language_code of this PartnerCustomBillingSettings.  # noqa: E501
        :rtype: DocumentLanguage
        """
        return self._template_language_code

    @template_language_code.setter
    def template_language_code(self, template_language_code):
        """Sets the template_language_code of this PartnerCustomBillingSettings.


        :param template_language_code: The template_language_code of this PartnerCustomBillingSettings.  # noqa: E501
        :type: DocumentLanguage
        """

        self._template_language_code = template_language_code

    @property
    def discount(self):
        """Gets the discount of this PartnerCustomBillingSettings.  # noqa: E501


        :return: The discount of this PartnerCustomBillingSettings.  # noqa: E501
        :rtype: Discount
        """
        return self._discount

    @discount.setter
    def discount(self, discount):
        """Sets the discount of this PartnerCustomBillingSettings.


        :param discount: The discount of this PartnerCustomBillingSettings.  # noqa: E501
        :type: Discount
        """

        self._discount = discount

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PartnerCustomBillingSettings, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PartnerCustomBillingSettings):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Billingo API v3

    This is a Billingo API v3 documentation. Our API based on REST software architectural style. API has resource-oriented URLs, accepts JSON-encoded request bodies and returns JSON-encoded responses. To use this API you have to generate a new API key on our [site](https://app.billingo.hu/api-key). After that, you can test your API key on this page.  # noqa: E501

    OpenAPI spec version: 3.0.14
    Contact: hello@billingo.hu
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Vat(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    allowed enum values
    """
    _0_ = "0%"
    _1_ = "1%"
    _10_ = "10%"
    _11_ = "11%"
    _12_ = "12%"
    _13_ = "13%"
    _14_ = "14%"
    _15_ = "15%"
    _16_ = "16%"
    _17_ = "17%"
    _18_ = "18%"
    _19_ = "19%"
    _2_ = "2%"
    _20_ = "20%"
    _21_ = "21%"
    _22_ = "22%"
    _23_ = "23%"
    _24_ = "24%"
    _25_ = "25%"
    _26_ = "26%"
    _27_ = "27%"
    _3_ = "3%"
    _4_ = "4%"
    _5_ = "5%"
    _5_5_ = "5,5%"
    _6_ = "6%"
    _7_ = "7%"
    _7_7_ = "7,7%"
    _8_ = "8%"
    _9_ = "9%"
    _9_5_ = "9,5%"
    AAM = "AAM"
    AM = "AM"
    EU = "EU"
    EUK = "EUK"
    F_AFA = "F.AFA"
    FAD = "FAD"
    K_AFA = "K.AFA"
    MAA = "MAA"
    TAM = "TAM"
    _KK = "ÁKK"
    _THK = "ÁTHK"
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
    }

    attribute_map = {
    }

    def __init__(self):  # noqa: E501
        """Vat - a model defined in Swagger"""  # noqa: E501
        self.discriminator = None

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Vat, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Vat):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Billingo API v3

    This is a Billingo API v3 documentation. Our API based on REST software architectural style. API has resource-oriented URLs, accepts JSON-encoded request bodies and returns JSON-encoded responses. To use this API you have to generate a new API key on our [site](https://app.billingo.hu/api-key). After that, you can test your API key on this page.  # noqa: E501

    OpenAPI spec version: 3.0.14
    Contact: hello@billingo.hu
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class Country(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    allowed enum values
    """
    EMPTY = ""
    AC = "AC"
    AD = "AD"
    AE = "AE"
    AF = "AF"
    AG = "AG"
    AI = "AI"
    AL = "AL"
    AM = "AM"
    AO = "AO"
    AQ = "AQ"
    AR = "AR"
    AS = "AS"
    AT = "AT"
    AU = "AU"
    AW = "AW"
    AX = "AX"
    AZ = "AZ"
    BA = "BA"
    BB = "BB"
    BD = "BD"
    BE = "BE"
    BF = "BF"
    BG = "BG"
    BH = "BH"
    BI = "BI"
    BJ = "BJ"
    BL = "BL"
    BM = "BM"
    BN = "BN"
    BO = "BO"
    BQ = "BQ"
    BR = "BR"
    BS = "BS"
    BT = "BT"
    BW = "BW"
    BY = "BY"
    BZ = "BZ"
    CA = "CA"
    CC = "CC"
    CD = "CD"
    CF = "CF"
    CG = "CG"
    CH = "CH"
    CI = "CI"
    CK = "CK"
    CL = "CL"
    CM = "CM"
    CN = "CN"
    CO = "CO"
    CR = "CR"
    CU = "CU"
    CV = "CV"
    CW = "CW"
    CX = "CX"
    CY = "CY"
    CZ = "CZ"
    DE = "DE"
    DG = "DG"
    DJ = "DJ"
    DK = "DK"
    DM = "DM"
    DO = "DO"
    DZ = "DZ"
    EA = "EA"
    EC = "EC"
    EE = "EE"
    EG = "EG"
    EH = "EH"
    ER = "ER"
    ES = "ES"
    ET = "ET"
    FI = "FI"
    FJ = "FJ"
    FK = "FK"
    FM = "FM"
    FO = "FO"
    FR = "FR"
    GA = "GA"
    GB = "GB"
    GD = "GD"
    GE = "GE"
    GF = "GF"
    GG = "GG"
    GH = "GH"
    GI = "GI"
    GL = "GL"
    GM = "GM"
    GN = "GN"
    GP = "GP"
    GQ = "GQ"
    GR = "GR"
    GS = "GS"
    GT = "GT"
    GU = "GU"
    GW = "GW"
    GY = "GY"
    HK = "HK"
    HN = "HN"
    HR = "HR"
    HT = "HT"
    HU = "HU"
    IC = "IC"
    ID = "ID"
    IE = "IE"
    IL = "IL"
    IM = "IM"
    IN = "IN"
    IO = "IO"
    IQ = "IQ"
    IR = "IR"
    IS = "IS"
    IT = "IT"
    JE = "JE"
    JM = "JM"
    JO = "JO"
    JP = "JP"
    KE = "KE"
    KG = "KG"
    KH = "KH"
    KI = "KI"
    KM = "KM"
    KN = "KN"
    KP = "KP"
    KR = "KR"
    KW = "KW"
    KY = "KY"
    KZ = "KZ"
    LA = "LA"
    LB = "LB"
    LC = "LC"
    LI = "LI"
    LK = "LK"
    LR = "LR"
    LS = "LS"
    LT = "LT"
    LU = "LU"
    LV = "LV"
    LY = "LY"
    MA = "MA"
    MC = "MC"
    MD = "MD"
    ME = "ME"
    MF = "MF"
    MG = "MG"
    MH = "MH"
    MK = "MK"
    ML = "ML"
    MM = "MM"
    MN = "MN"
    MO = "MO"
    MP = "MP"
    MQ = "MQ"
    MR = "MR"
    MS = "MS"
    MT = "MT"
    MU = "MU"
    MV = "MV"
    MW = "MW"
    MX = "MX"
    MY = "MY"
    MZ = "MZ"
    NA = "NA"
    NC = "NC"
    NE = "NE"
    NF = "NF"
    NG = "NG"
    NI = "NI"
    NL = "NL"
    NO = "NO"
    NP = "NP"
    NR = "NR"
    NU = "NU"
    NZ = "NZ"
    OM = "OM"
    PA = "PA"
    PE = "PE"
    PF = "PF"
    PG = "PG"
    PH = "PH"
    PK = "PK"
    PL = "PL"
    PM = "PM"
    PN = "PN"
    PR = "PR"
    PS = "PS"
    PT = "PT"
    PW = "PW"
    PY = "PY"
    QA = "QA"
    RE = "RE"
    RO = "RO"
    RS = "RS"
    RU = "RU"
    RW = "RW"
    SA = "SA"
    SB = "SB"
    SC = "SC"
    SD = "SD"
    SE = "SE"
    SG = "SG"
    SH = "SH"
    SI = "SI"
    SJ = "SJ"
    SK = "SK"
    SL = "SL"
    SM = "SM"
    SN = "SN"
    SO = "SO"
    SR = "SR"
    SS = "SS"
    ST = "ST"
    SV = "SV"
    SX = "SX"
    SY = "SY"
    SZ = "SZ"
    TA = "TA"
    TC = "TC"
    TD = "TD"
    TF = "TF"
    TG = "TG"
    TH = "TH"
    TJ = "TJ"
    TK = "TK"
    TL = "TL"
    TM = "TM"
    TN = "TN"
    TO = "TO"
    TR = "TR"
    TT = "TT"
    TV = "TV"
    TW = "TW"
    TZ = "TZ"
    UA = "UA"
    UG = "UG"
    UM = "UM"
    US = "US"
    UY = "UY"
    UZ = "UZ"
    VA = "VA"
    VC = "VC"
    VE = "VE"
    VG = "VG"
    VI = "VI"
    VN = "VN"
    VU = "VU"
    WF = "WF"
    WS = "WS"
    XA = "XA"
    XB = "XB"
    XK = "XK"
    YE = "YE"
    YT = "YT"
    ZA = "ZA"
    ZM = "ZM"
    ZW = "ZW"
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
    }

    attribute_map = {
    }

    def __init__(self):  # noqa: E501
        """Country - a model defined in Swagger"""  # noqa: E501
        self.discriminator = None

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(Country, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Country):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from billingo.api.bank_account_api import BankAccountApi
from billingo.api.currency_api import CurrencyApi
from billingo.api.document_api import DocumentApi
from billingo.api.document_block_api import DocumentBlockApi
from billingo.api.document_export_api import DocumentExportApi
from billingo.api.organization_api import OrganizationApi
from billingo.api.partner_api import PartnerApi
from billingo.api.product_api import ProductApi
from billingo.api.spending_api import SpendingApi
from billingo.api.util_api import UtilApi



# coding: utf-8

"""
    Billingo API v3

    This is a Billingo API v3 documentation. Our API based on REST software architectural style. API has resource-oriented URLs, accepts JSON-encoded request bodies and returns JSON-encoded responses. To use this API you have to generate a new API key on our [site](https://app.billingo.hu/api-key). After that, you can test your API key on this page.  # noqa: E501

    OpenAPI spec version: 3.0.14
    Contact: hello@billingo.hu
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from billingo.api_client import ApiClient


class BankAccountApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def create_bank_account(self, body, **kwargs):  # noqa: E501
        """Create a bank account  # noqa: E501

        Create a new bank account. Returns a bank account object if the create is succeded.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_bank_account(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param BankAccount body: BankAccount object that you would like to store. (required)
        :return: BankAccount
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.create_bank_account_with_http_info(body, **kwargs)  # noqa: E501
        else:
            (data) = self.create_bank_account_with_http_info(body, **kwargs)  # noqa: E501
            return data

    def create_bank_account_with_http_info(self, body, **kwargs):  # noqa: E501
        """Create a bank account  # noqa: E501

        Create a new bank account. Returns a bank account object if the create is succeded.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_bank_account_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param BankAccount body: BankAccount object that you would like to store. (required)
        :return: BankAccount
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_bank_account" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `create_bank_account`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/bank-accounts', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BankAccount',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_bank_account(self, id, **kwargs):  # noqa: E501
        """Delete a bank account  # noqa: E501

        Delete an existing bank account.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_bank_account(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.delete_bank_account_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.delete_bank_account_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def delete_bank_account_with_http_info(self, id, **kwargs):  # noqa: E501
        """Delete a bank account  # noqa: E501

        Delete an existing bank account.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_bank_account_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_bank_account" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `delete_bank_account`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/bank-accounts/{id}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_bank_account(self, id, **kwargs):  # noqa: E501
        """Retrieve a bank account  # noqa: E501

        Retrieves the details of an existing bank account.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_bank_account(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: (required)
        :return: BankAccount
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_bank_account_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_bank_account_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_bank_account_with_http_info(self, id, **kwargs):  # noqa: E501
        """Retrieve a bank account  # noqa: E501

        Retrieves the details of an existing bank account.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_bank_account_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int id: (required)
        :return: BankAccount
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_bank_account" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_bank_account`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/bank-accounts/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BankAccount',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_bank_account(self, **kwargs):  # noqa: E501
        """List all bank account  # noqa: E501

        Returns a list of your bank accounts. The bank accounts are returned sorted by creation date, with the most recent bank account appearing first.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_bank_account(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page:
        :param int per_page:
        :return: BankAccountList
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.list_bank_account_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.list_bank_account_with_http_info(**kwargs)  # noqa: E501
            return data

    def list_bank_account_with_http_info(self, **kwargs):  # noqa: E501
        """List all bank account  # noqa: E501

        Returns a list of your bank accounts. The bank accounts are returned sorted by creation date, with the most recent bank account appearing first.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_bank_account_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int page:
        :param int per_page:
        :return: BankAccountList
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['page', 'per_page']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_bank_account" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'page' in params:
            query_params.append(('page', params['page']))  # noqa: E501
        if 'per_page' in params:
            query_params.append(('per_page', params['per_page']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/bank-accounts', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BankAccountList',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_bank_account(self, body, id, **kwargs):  # noqa: E501
        """Update a bank account  # noqa: E501

        Update an existing bank accounts. Returns a bank account object if the update is succeded.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_bank_account(body, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param BankAccount body: Bank account object that you would like to update. (required)
        :param int id: (required)
        :return: BankAccount
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.update_bank_account_with_http_info(body, id, **kwargs)  # noqa: E501
        else:
            (data) = self.update_bank_account_with_http_info(body, id, **kwargs)  # noqa: E501
            return data

    def update_bank_account_with_http_info(self, body, id, **kwargs):  # noqa: E501
        """Update a bank account  # noqa: E501

        Update an existing bank accounts. Returns a bank account object if the update is succeded.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_bank_account_with_http_info(body, id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param BankAccount body: Bank account object that you would like to update. (required)
        :param int id: (required)
        :return: BankAccount
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body', 'id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_bank_account" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'body' is set
        if ('body' not in params or
                params['body'] is None):
            raise ValueError("Missing the required parameter `body` when calling `update_bank_account`")  # noqa: E501
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `update_bank_account`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['api_key']  # noqa: E501

        return self.api_client.call_api(
            '/bank-accounts/{id}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='BankAccount',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Billingo API v3

    This is a Billingo API v3 documentation. Our API based on REST software architectural style. API has resource-oriented URLs, accepts JSON-encoded request bodies and returns JSON-encoded responses. To use this API you have to generate a new API key on our [site](https://app.billingo.hu/api-key). After that, you can test your API key on this page.  # noqa: E501

    OpenAPI spec version: 3.0.14
    Contact: hello@billingo.hu
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PaymentHistory(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        '_date': 'date',
        'price': 'float',
        'payment_method': 'PaymentMethod',
        'voucher_number': 'str',
        'conversion_rate': 'float'
    }

    attribute_map = {
        '_date': 'date',
        'price': 'price',
        'payment_method': 'payment_method',
        'voucher_number': 'voucher_number',
        'conversion_rate': 'conversion_rate'
    }

    def __init__(self, _date=None, price=None, payment_method=None, voucher_number=None, conversion_rate=None):  # noqa: E501
        """PaymentHistory - a model defined in Swagger"""  # noqa: E501
        self.__date = None
        self._price = None
        self._payment_method = None
        self._voucher_number = None
        self._conversion_rate = None
        self.discriminator = None
        self._date = _date
        self.price = price
        self.payment_method = payment_method
        if voucher_number is not None:
            self.voucher_number = voucher_number
        if conversion_rate is not None:
            self.conversion_rate = conversion_rate

    @property
    def _date(self):
        """Gets the _date of this PaymentHistory.  # noqa: E501


        :return: The _date of this PaymentHistory.  # noqa: E501
        :rtype: date
        """
        return self.__date

    @_date.setter
    def _date(self, _date):
        """Sets the _date of this PaymentHistory.


        :param _date: The _date of this PaymentHistory.  # noqa: E501
        :type: date
        """
        if _date is None:
            raise ValueError("Invalid value for `_date`, must not be `None`")  # noqa: E501

        self.__date = _date

    @property
    def price(self):
        """Gets the price of this PaymentHistory.  # noqa: E501


        :return: The price of this PaymentHistory.  # noqa: E501
        :rtype: float
        """
        return self._price

    @price.setter
    def price(self, price):
        """Sets the price of this PaymentHistory.


        :param price: The price of this PaymentHistory.  # noqa: E501
        :type: float
        """
        if price is None:
            raise ValueError("Invalid value for `price`, must not be `None`")  # noqa: E501

        self._price = price

    @property
    def payment_method(self):
        """Gets the payment_method of this PaymentHistory.  # noqa: E501


        :return: The payment_method of this PaymentHistory.  # noqa: E501
        :rtype: PaymentMethod
        """
        return self._payment_method

    @payment_method.setter
    def payment_method(self, payment_method):
        """Sets the payment_method of this PaymentHistory.


        :param payment_method: The payment_method of this PaymentHistory.  # noqa: E501
        :type: PaymentMethod
        """
        if payment_method is None:
            raise ValueError("Invalid value for `payment_method`, must not be `None`")  # noqa: E501

        self._payment_method = payment_method

    @property
    def voucher_number(self):
        """Gets the voucher_number of this PaymentHistory.  # noqa: E501


        :return: The voucher_number of this PaymentHistory.  # noqa: E501
        :rtype: str
        """
        return self._voucher_number

    @voucher_number.setter
    def voucher_number(self, voucher_number):
        """Sets the voucher_number of this PaymentHistory.


        :param voucher_number: The voucher_number of this PaymentHistory.  # noqa: E501
        :type: str
        """

        self._voucher_number = voucher_number

    @property
    def conversion_rate(self):
        """Gets the conversion_rate of this PaymentHistory.  # noqa: E501


        :return: The conversion_rate of this PaymentHistory.  # noqa: E501
        :rtype: float
        """
        return self._conversion_rate

    @conversion_rate.setter
    def conversion_rate(self, conversion_rate):
        """Sets the conversion_rate of this PaymentHistory.


        :param conversion_rate: The conversion_rate of this PaymentHistory.  # noqa: E501
        :type: float
        """

        self._conversion_rate = conversion_rate

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PaymentHistory, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PaymentHistory):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Billingo API v3

    This is a Billingo API v3 documentation. Our API based on REST software architectural style. API has resource-oriented URLs, accepts JSON-encoded request bodies and returns JSON-encoded responses. To use this API you have to generate a new API key on our [site](https://app.billingo.hu/api-key). After that, you can test your API key on this page.  # noqa: E501

    OpenAPI spec version: 3.0.14
    Contact: hello@billingo.hu
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ReceiptInsert(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'vendor_id': 'str',
        'partner_id': 'int',
        'name': 'str',
        'emails': 'list[str]',
        'block_id': 'int',
        'type': 'DocumentType',
        'payment_method': 'PaymentMethod',
        'currency': 'Currency',
        'conversion_rate': 'float',
        'electronic': 'bool',
        'items': 'list[OneOfReceiptInsertItemsItems]'
    }

    attribute_map = {
        'vendor_id': 'vendor_id',
        'partner_id': 'partner_id',
        'name': 'name',
        'emails': 'emails',
        'block_id': 'block_id',
        'type': 'type',
        'payment_method': 'payment_method',
        'currency': 'currency',
        'conversion_rate': 'conversion_rate',
        'electronic': 'electronic',
        'items': 'items'
    }

    def __init__(self, vendor_id=None, partner_id=None, name=None, emails=None, block_id=None, type=None, payment_method=None, currency=None, conversion_rate=None, electronic=False, items=None):  # noqa: E501
        """ReceiptInsert - a model defined in Swagger"""  # noqa: E501
        self._vendor_id = None
        self._partner_id = None
        self._name = None
        self._emails = None
        self._block_id = None
        self._type = None
        self._payment_method = None
        self._currency = None
        self._conversion_rate = None
        self._electronic = None
        self._items = None
        self.discriminator = None
        if vendor_id is not None:
            self.vendor_id = vendor_id
        if partner_id is not None:
            self.partner_id = partner_id
        if name is not None:
            self.name = name
        if emails is not None:
            self.emails = emails
        self.block_id = block_id
        self.type = type
        self.payment_method = payment_method
        self.currency = currency
        if conversion_rate is not None:
            self.conversion_rate = conversion_rate
        if electronic is not None:
            self.electronic = electronic
        if items is not None:
            self.items = items

    @property
    def vendor_id(self):
        """Gets the vendor_id of this ReceiptInsert.  # noqa: E501


        :return: The vendor_id of this ReceiptInsert.  # noqa: E501
        :rtype: str
        """
        return self._vendor_id

    @vendor_id.setter
    def vendor_id(self, vendor_id):
        """Sets the vendor_id of this ReceiptInsert.


        :param vendor_id: The vendor_id of this ReceiptInsert.  # noqa: E501
        :type: str
        """

        self._vendor_id = vendor_id

    @property
    def partner_id(self):
        """Gets the partner_id of this ReceiptInsert.  # noqa: E501


        :return: The partner_id of this ReceiptInsert.  # noqa: E501
        :rtype: int
        """
        return self._partner_id

    @partner_id.setter
    def partner_id(self, partner_id):
        """Sets the partner_id of this ReceiptInsert.


        :param partner_id: The partner_id of this ReceiptInsert.  # noqa: E501
        :type: int
        """

        self._partner_id = partner_id

    @property
    def name(self):
        """Gets the name of this ReceiptInsert.  # noqa: E501


        :return: The name of this ReceiptInsert.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ReceiptInsert.


        :param name: The name of this ReceiptInsert.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def emails(self):
        """Gets the emails of this ReceiptInsert.  # noqa: E501


        :return: The emails of this ReceiptInsert.  # noqa: E501
        :rtype: list[str]
        """
        return self._emails

    @emails.setter
    def emails(self, emails):
        """Sets the emails of this ReceiptInsert.


        :param emails: The emails of this ReceiptInsert.  # noqa: E501
        :type: list[str]
        """

        self._emails = emails

    @property
    def block_id(self):
        """Gets the block_id of this ReceiptInsert.  # noqa: E501


        :return: The block_id of this ReceiptInsert.  # noqa: E501
        :rtype: int
        """
        return self._block_id

    @block_id.setter
    def block_id(self, block_id):
        """Sets the block_id of this ReceiptInsert.


        :param block_id: The block_id of this ReceiptInsert.  # noqa: E501
        :type: int
        """
        if block_id is None:
            raise ValueError("Invalid value for `block_id`, must not be `None`")  # noqa: E501

        self._block_id = block_id

    @property
    def type(self):
        """Gets the type of this ReceiptInsert.  # noqa: E501


        :return: The type of this ReceiptInsert.  # noqa: E501
        :rtype: DocumentType
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ReceiptInsert.


        :param type: The type of this ReceiptInsert.  # noqa: E501
        :type: DocumentType
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def payment_method(self):
        """Gets the payment_method of this ReceiptInsert.  # noqa: E501


        :return: The payment_method of this ReceiptInsert.  # noqa: E501
        :rtype: PaymentMethod
        """
        return self._payment_method

    @payment_method.setter
    def payment_method(self, payment_method):
        """Sets the payment_method of this ReceiptInsert.


        :param payment_method: The payment_method of this ReceiptInsert.  # noqa: E501
        :type: PaymentMethod
        """
        if payment_method is None:
            raise ValueError("Invalid value for `payment_method`, must not be `None`")  # noqa: E501

        self._payment_method = payment_method

    @property
    def currency(self):
        """Gets the currency of this ReceiptInsert.  # noqa: E501


        :return: The currency of this ReceiptInsert.  # noqa: E501
        :rtype: Currency
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this ReceiptInsert.


        :param currency: The currency of this ReceiptInsert.  # noqa: E501
        :type: Currency
        """
        if currency is None:
            raise ValueError("Invalid value for `currency`, must not be `None`")  # noqa: E501

        self._currency = currency

    @property
    def conversion_rate(self):
        """Gets the conversion_rate of this ReceiptInsert.  # noqa: E501


        :return: The conversion_rate of this ReceiptInsert.  # noqa: E501
        :rtype: float
        """
        return self._conversion_rate

    @conversion_rate.setter
    def conversion_rate(self, conversion_rate):
        """Sets the conversion_rate of this ReceiptInsert.


        :param conversion_rate: The conversion_rate of this ReceiptInsert.  # noqa: E501
        :type: float
        """

        self._conversion_rate = conversion_rate

    @property
    def electronic(self):
        """Gets the electronic of this ReceiptInsert.  # noqa: E501


        :return: The electronic of this ReceiptInsert.  # noqa: E501
        :rtype: bool
        """
        return self._electronic

    @electronic.setter
    def electronic(self, electronic):
        """Sets the electronic of this ReceiptInsert.


        :param electronic: The electronic of this ReceiptInsert.  # noqa: E501
        :type: bool
        """

        self._electronic = electronic

    @property
    def items(self):
        """Gets the items of this ReceiptInsert.  # noqa: E501


        :return: The items of this ReceiptInsert.  # noqa: E501
        :rtype: list[OneOfReceiptInsertItemsItems]
        """
        return self._items

    @items.setter
    def items(self, items):
        """Sets the items of this ReceiptInsert.


        :param items: The items of this ReceiptInsert.  # noqa: E501
        :type: list[OneOfReceiptInsertItemsItems]
        """

        self._items = items

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ReceiptInsert, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ReceiptInsert):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Billingo API v3

    This is a Billingo API v3 documentation. Our API based on REST software architectural style. API has resource-oriented URLs, accepts JSON-encoded request bodies and returns JSON-encoded responses. To use this API you have to generate a new API key on our [site](https://app.billingo.hu/api-key). After that, you can test your API key on this page.  # noqa: E501

    OpenAPI spec version: 3.0.14
    Contact: hello@billingo.hu
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class DocumentExportFilterExtra(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'tensoft_vkod': 'str',
        'ledger_number': 'LedgerNumberInformation',
        'forintsoft_konyvelesi_naplo_szam': 'str',
        'positive_ledger_number': 'str',
        'negative_ledger_number': 'str',
        'rlb_kata': 'bool',
        'rlb_note': 'str',
        'novitax_naplokod': 'str',
        'use_gross_values': 'bool'
    }

    attribute_map = {
        'tensoft_vkod': 'tensoft_vkod',
        'ledger_number': 'ledger_number',
        'forintsoft_konyvelesi_naplo_szam': 'forintsoft_konyvelesi_naplo_szam',
        'positive_ledger_number': 'positive_ledger_number',
        'negative_ledger_number': 'negative_ledger_number',
        'rlb_kata': 'rlb_kata',
        'rlb_note': 'rlb_note',
        'novitax_naplokod': 'novitax_naplokod',
        'use_gross_values': 'use_gross_values'
    }

    def __init__(self, tensoft_vkod=None, ledger_number=None, forintsoft_konyvelesi_naplo_szam=None, positive_ledger_number=None, negative_ledger_number=None, rlb_kata=None, rlb_note=None, novitax_naplokod=None, use_gross_values=None):  # noqa: E501
        """DocumentExportFilterExtra - a model defined in Swagger"""  # noqa: E501
        self._tensoft_vkod = None
        self._ledger_number = None
        self._forintsoft_konyvelesi_naplo_szam = None
        self._positive_ledger_number = None
        self._negative_ledger_number = None
        self._rlb_kata = None
        self._rlb_note = None
        self._novitax_naplokod = None
        self._use_gross_values = None
        self.discriminator = None
        if tensoft_vkod is not None:
            self.tensoft_vkod = tensoft_vkod
        if ledger_number is not None:
            self.ledger_number = ledger_number
        if forintsoft_konyvelesi_naplo_szam is not None:
            self.forintsoft_konyvelesi_naplo_szam = forintsoft_konyvelesi_naplo_szam
        if positive_ledger_number is not None:
            self.positive_ledger_number = positive_ledger_number
        if negative_ledger_number is not None:
            self.negative_ledger_number = negative_ledger_number
        if rlb_kata is not None:
            self.rlb_kata = rlb_kata
        if rlb_note is not None:
            self.rlb_note = rlb_note
        if novitax_naplokod is not None:
            self.novitax_naplokod = novitax_naplokod
        if use_gross_values is not None:
            self.use_gross_values = use_gross_values

    @property
    def tensoft_vkod(self):
        """Gets the tensoft_vkod of this DocumentExportFilterExtra.  # noqa: E501


        :return: The tensoft_vkod of this DocumentExportFilterExtra.  # noqa: E501
        :rtype: str
        """
        return self._tensoft_vkod

    @tensoft_vkod.setter
    def tensoft_vkod(self, tensoft_vkod):
        """Sets the tensoft_vkod of this DocumentExportFilterExtra.


        :param tensoft_vkod: The tensoft_vkod of this DocumentExportFilterExtra.  # noqa: E501
        :type: str
        """

        self._tensoft_vkod = tensoft_vkod

    @property
    def ledger_number(self):
        """Gets the ledger_number of this DocumentExportFilterExtra.  # noqa: E501


        :return: The ledger_number of this DocumentExportFilterExtra.  # noqa: E501
        :rtype: LedgerNumberInformation
        """
        return self._ledger_number

    @ledger_number.setter
    def ledger_number(self, ledger_number):
        """Sets the ledger_number of this DocumentExportFilterExtra.


        :param ledger_number: The ledger_number of this DocumentExportFilterExtra.  # noqa: E501
        :type: LedgerNumberInformation
        """

        self._ledger_number = ledger_number

    @property
    def forintsoft_konyvelesi_naplo_szam(self):
        """Gets the forintsoft_konyvelesi_naplo_szam of this DocumentExportFilterExtra.  # noqa: E501


        :return: The forintsoft_konyvelesi_naplo_szam of this DocumentExportFilterExtra.  # noqa: E501
        :rtype: str
        """
        return self._forintsoft_konyvelesi_naplo_szam

    @forintsoft_konyvelesi_naplo_szam.setter
    def forintsoft_konyvelesi_naplo_szam(self, forintsoft_konyvelesi_naplo_szam):
        """Sets the forintsoft_konyvelesi_naplo_szam of this DocumentExportFilterExtra.


        :param forintsoft_konyvelesi_naplo_szam: The forintsoft_konyvelesi_naplo_szam of this DocumentExportFilterExtra.  # noqa: E501
        :type: str
        """

        self._forintsoft_konyvelesi_naplo_szam = forintsoft_konyvelesi_naplo_szam

    @property
    def positive_ledger_number(self):
        """Gets the positive_ledger_number of this DocumentExportFilterExtra.  # noqa: E501


        :return: The positive_ledger_number of this DocumentExportFilterExtra.  # noqa: E501
        :rtype: str
        """
        return self._positive_ledger_number

    @positive_ledger_number.setter
    def positive_ledger_number(self, positive_ledger_number):
        """Sets the positive_ledger_number of this DocumentExportFilterExtra.


        :param positive_ledger_number: The positive_ledger_number of this DocumentExportFilterExtra.  # noqa: E501
        :type: str
        """

        self._positive_ledger_number = positive_ledger_number

    @property
    def negative_ledger_number(self):
        """Gets the negative_ledger_number of this DocumentExportFilterExtra.  # noqa: E501


        :return: The negative_ledger_number of this DocumentExportFilterExtra.  # noqa: E501
        :rtype: str
        """
        return self._negative_ledger_number

    @negative_ledger_number.setter
    def negative_ledger_number(self, negative_ledger_number):
        """Sets the negative_ledger_number of this DocumentExportFilterExtra.


        :param negative_ledger_number: The negative_ledger_number of this DocumentExportFilterExtra.  # noqa: E501
        :type: str
        """

        self._negative_ledger_number = negative_ledger_number

    @property
    def rlb_kata(self):
        """Gets the rlb_kata of this DocumentExportFilterExtra.  # noqa: E501


        :return: The rlb_kata of this DocumentExportFilterExtra.  # noqa: E501
        :rtype: bool
        """
        return self._rlb_kata

    @rlb_kata.setter
    def rlb_kata(self, rlb_kata):
        """Sets the rlb_kata of this DocumentExportFilterExtra.


        :param rlb_kata: The rlb_kata of this DocumentExportFilterExtra.  # noqa: E501
        :type: bool
        """

        self._rlb_kata = rlb_kata

    @property
    def rlb_note(self):
        """Gets the rlb_note of this DocumentExportFilterExtra.  # noqa: E501


        :return: The rlb_note of this DocumentExportFilterExtra.  # noqa: E501
        :rtype: str
        """
        return self._rlb_note

    @rlb_note.setter
    def rlb_note(self, rlb_note):
        """Sets the rlb_note of this DocumentExportFilterExtra.


        :param rlb_note: The rlb_note of this DocumentExportFilterExtra.  # noqa: E501
        :type: str
        """

        self._rlb_note = rlb_note

    @property
    def novitax_naplokod(self):
        """Gets the novitax_naplokod of this DocumentExportFilterExtra.  # noqa: E501


        :return: The novitax_naplokod of this DocumentExportFilterExtra.  # noqa: E501
        :rtype: str
        """
        return self._novitax_naplokod

    @novitax_naplokod.setter
    def novitax_naplokod(self, novitax_naplokod):
        """Sets the novitax_naplokod of this DocumentExportFilterExtra.


        :param novitax_naplokod: The novitax_naplokod of this DocumentExportFilterExtra.  # noqa: E501
        :type: str
        """

        self._novitax_naplokod = novitax_naplokod

    @property
    def use_gross_values(self):
        """Gets the use_gross_values of this DocumentExportFilterExtra.  # noqa: E501


        :return: The use_gross_values of this DocumentExportFilterExtra.  # noqa: E501
        :rtype: bool
        """
        return self._use_gross_values

    @use_gross_values.setter
    def use_gross_values(self, use_gross_values):
        """Sets the use_gross_values of this DocumentExportFilterExtra.


        :param use_gross_values: The use_gross_values of this DocumentExportFilterExtra.  # noqa: E501
        :type: bool
        """

        self._use_gross_values = use_gross_values

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(DocumentExportFilterExtra, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DocumentExportFilterExtra):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Billingo API v3

    This is a Billingo API v3 documentation. Our API based on REST software architectural style. API has resource-oriented URLs, accepts JSON-encoded request bodies and returns JSON-encoded responses. To use this API you have to generate a new API key on our [site](https://app.billingo.hu/api-key). After that, you can test your API key on this page.  # noqa: E501

    OpenAPI spec version: 3.0.14
    Contact: hello@billingo.hu
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ServerTime(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'epoch': 'int',
        'formatted': 'str',
        'w3c': 'str',
        'timezone': 'str'
    }

    attribute_map = {
        'epoch': 'epoch',
        'formatted': 'formatted',
        'w3c': 'w3c',
        'timezone': 'timezone'
    }

    def __init__(self, epoch=None, formatted=None, w3c=None, timezone=None):  # noqa: E501
        """ServerTime - a model defined in Swagger"""  # noqa: E501
        self._epoch = None
        self._formatted = None
        self._w3c = None
        self._timezone = None
        self.discriminator = None
        if epoch is not None:
            self.epoch = epoch
        if formatted is not None:
            self.formatted = formatted
        if w3c is not None:
            self.w3c = w3c
        if timezone is not None:
            self.timezone = timezone

    @property
    def epoch(self):
        """Gets the epoch of this ServerTime.  # noqa: E501


        :return: The epoch of this ServerTime.  # noqa: E501
        :rtype: int
        """
        return self._epoch

    @epoch.setter
    def epoch(self, epoch):
        """Sets the epoch of this ServerTime.


        :param epoch: The epoch of this ServerTime.  # noqa: E501
        :type: int
        """

        self._epoch = epoch

    @property
    def formatted(self):
        """Gets the formatted of this ServerTime.  # noqa: E501


        :return: The formatted of this ServerTime.  # noqa: E501
        :rtype: str
        """
        return self._formatted

    @formatted.setter
    def formatted(self, formatted):
        """Sets the formatted of this ServerTime.


        :param formatted: The formatted of this ServerTime.  # noqa: E501
        :type: str
        """

        self._formatted = formatted

    @property
    def w3c(self):
        """Gets the w3c of this ServerTime.  # noqa: E501


        :return: The w3c of this ServerTime.  # noqa: E501
        :rtype: str
        """
        return self._w3c

    @w3c.setter
    def w3c(self, w3c):
        """Sets the w3c of this ServerTime.


        :param w3c: The w3c of this ServerTime.  # noqa: E501
        :type: str
        """

        self._w3c = w3c

    @property
    def timezone(self):
        """Gets the timezone of this ServerTime.  # noqa: E501


        :return: The timezone of this ServerTime.  # noqa: E501
        :rtype: str
        """
        return self._timezone

    @timezone.setter
    def timezone(self, timezone):
        """Sets the timezone of this ServerTime.


        :param timezone: The timezone of this ServerTime.  # noqa: E501
        :type: str
        """

        self._timezone = timezone

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ServerTime, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ServerTime):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
